@@ -40,12 +40,21 @@ class Sparkle(Animation):
     :param float speed: Animation speed in seconds, e.g. ``0.1``.
     :param color: Animation color in ``(r, g, b)`` tuple, or ``0x000000`` hex format.
     :param num_sparkles: Number of sparkles to generate per animation cycle.
+    :param mask: array to limit sparkles within range of the mask
     """
 
     # pylint: disable=too-many-arguments
-    def __init__(self, pixel_object, speed, color, num_sparkles=1, name=None):
+    def __init__(
+        self, pixel_object, speed, color, num_sparkles=1, name=None, mask=None
+    ):
         if len(pixel_object) < 2:
             raise ValueError("Sparkle needs at least 2 pixels")
+        if mask:
+            self._mask = mask
+        else:
+            self._mask = []
+        if len(self._mask) >= len(pixel_object):
+            raise ValueError("Sparkle mask should be smaller than number pixel array")
         self._half_color = color
         self._dim_color = color
         self._sparkle_color = color
@@ -66,11 +75,13 @@ class Sparkle(Animation):
         self._dim_color = dim_color
         self._sparkle_color = color
 
+    def _random_in_mask(self):
+        if len(self._mask) == 0:
+            return random.randint(0, (len(self.pixel_object) - 1))
+        return self._mask[random.randint(0, (len(self._mask) - 1))]
+
     def draw(self):
-        self._pixels = [
-            random.randint(0, (len(self.pixel_object) - 1))
-            for _ in range(self._num_sparkles)
-        ]
+        self._pixels = [self._random_in_mask() for _ in range(self._num_sparkles)]
         for pixel in self._pixels:
             self.pixel_object[pixel] = self._sparkle_color
 
@@ -78,4 +89,5 @@ class Sparkle(Animation):
         self.show()
         for pixel in self._pixels:
             self.pixel_object[pixel % self._num_pixels] = self._half_color
-            self.pixel_object[(pixel + 1) % self._num_pixels] = self._dim_color
+            if (pixel + 1) % self._num_pixels in self._mask:
+                self.pixel_object[(pixel + 1) % self._num_pixels] = self._dim_color
